@@ -27,7 +27,6 @@
 #include <string.h>
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-i18n.h>
-#include <egg-screen-exec.h>
 #include <gconf/gconf-client.h>
 
 #include "netstatus-icon.h"
@@ -311,10 +310,13 @@ netstatus_dialog_set_iface_name (NetstatusDialogData *data,
   const char *iface_name;
 
   iface_name = gtk_entry_get_text (entry);
-  netstatus_iface_set_name (data->iface, iface_name);
+  if (iface_name && iface_name [0])
+    {
+      netstatus_iface_set_name (data->iface, iface_name);
 
-  gtk_widget_set_sensitive (data->configure_button,
-			    !netstatus_iface_get_is_loopback (data->iface));
+      gtk_widget_set_sensitive (data->configure_button,
+				!netstatus_iface_get_is_loopback (data->iface));
+    }
 }
 
 static void
@@ -471,7 +473,7 @@ netstatus_iface_configure (GtkWidget           *configure_button,
   screen = gtk_window_get_screen (GTK_WINDOW (dialog_data->dialog));
 
   error = NULL;
-  if (!egg_screen_execute_command_line_async (screen, command->str, &error))
+  if (!gdk_spawn_command_line_on_screen (screen, command->str, &error))
     {
       GtkWidget *error_dialog;
 
